@@ -24,13 +24,11 @@
 
 #include <stdio.h>
 #include <ETL/angle>
-#include <ETL/clock>
 #include <ETL/bezier>
 #include <ETL/hermite>
 
 /* === M A C R O S ========================================================= */
 
-using namespace std;
 using namespace etl;
 
 /* === C L A S S E S ======================================================= */
